basket_test: Test for the results of a basket trial

View source: R/basket_test.R

basket_testR Documentation

Test for the results of a basket trial

Description

Generic function for calculating the posterior probabilities of a basket trial design.

Usage

basket_test(design, ...)

Arguments

design

An object created with one of the setup_ functions from the basksim package or the baskwrap package.

...

Further arguments.

Value

A numeric vector of posterior probabilities for all strata.

Examples

design_x <- setup_fujikawa_x(k = 3, p0 = 0.2, backend = "exact")
basket_test(design = design_x, n = 20, r = c(2, 7, 19), lambda = 0.95,
            epsilon = 2, tau = 0,
            logbase = exp(1))

baskwrap documentation built on March 19, 2026, 5:09 p.m.