ecd: Calculate the Expected Number of Correct Decisions for a...

View source: R/ecd.R

ecdR Documentation

Calculate the Expected Number of Correct Decisions for a Basket Trial Design

Description

Generic function for calculating the expected number of correct decisions of a basket trial design. It defaults to the function basksim::ecd.

Usage

ecd(design, ...)

## Default S3 method:
ecd(design, ...)

Arguments

design

An object created with one of the setup functions from the basksim package.

...

Further arguments.

Value

A numeric value.

Examples

design <- setup_fujikawa_x(k = 3, p0 = 0.2)
ecd(design = design, n = 20, p1 = c(0.2, 0.5, 0.5), lambda = 0.95,
     design_params = list(epsilon = 2, tau = 0), iter = 100)

baskwrap documentation built on March 19, 2026, 5:09 p.m.