get_scenarios: Generate a matrix of default outcome scenarios

View source: R/get_scenarios.R

get_scenariosR Documentation

Generate a matrix of default outcome scenarios

Description

This functions generates a matrix of k+1 default outcome scenarios, ranging from no responsive strata (global null scenarios) to all responsive strata (global alternative scenario). It is a wrapper of the function basksim::get_scenarios.

Usage

get_scenarios(design, p1)

Arguments

design

An object created with one of the setup functions.

p1

Probability under the alternative hypothesis.

Details

No backend switching is implemented in this function because baskexact::get_scenarios() does precisely the same thing as basksim::get_scenarios().

Value

A matrix with k rows and k + 1 columns.

Examples

# Example for a basket trial with Fujikawa's Design
design <- setup_fujikawa_x(k = 3, p0 = 0.2)
get_scenarios(design, p1 = 0.5)

baskwrap documentation built on March 19, 2026, 5:09 p.m.