setup_fujikawa_x: Set up a Fujikawa design object with flexible backend

View source: R/class.R

setup_fujikawa_xR Documentation

Set up a Fujikawa design object with flexible backend

Description

The fujikawa_x S3 class is similar to the basksim::fujikawa class, but it has an additional parameter backend, that allows users to decide which backend should be used for calculation of details (i.e. rejection rates, power, type-I error rate etc.): the basksim package or the baskexact package.

Usage

setup_fujikawa_x(k, p0, shape1 = 1, shape2 = 1, backend = "sim")

Arguments

k

The number of baskets.

p0

A common probability under the null hypothesis.

shape1

First common shape parameter of the beta prior.

shape2

Second common shape parameter of the beta prior.

backend

A string, either "sim" or "exact" for specifying the use of the basksim package or the baskexact package for calculation of basket trial details.

Value

An object of class fujikawa_x.

Examples

design <- setup_fujikawa_x(k = 3, p0 = 0.2)

baskwrap documentation built on March 19, 2026, 5:09 p.m.