| basket_test | R Documentation |
Generic function for calculating the posterior probabilities of a basket trial design.
basket_test(design, ...)
design |
An object created with one of the |
... |
Further arguments. |
A numeric vector of posterior probabilities for all strata.
design_x <- setup_fujikawa_x(k = 3, p0 = 0.2, backend = "exact")
basket_test(design = design_x, n = 20, r = c(2, 7, 19), lambda = 0.95,
epsilon = 2, tau = 0,
logbase = exp(1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.