| basket_test.fujikawa_x | R Documentation |
This function is a wrapper of baskexact::basket_test(). It returns the
posterior probabilities of a basket trial including borrowing.
## S3 method for class 'fujikawa_x'
basket_test(
design,
n,
r,
lambda,
epsilon,
tau,
logbase = 2,
weight_fun = weights_jsd,
weight_params = list(epsilon = epsilon, tau = tau, logbase = logbase),
...
)
design |
An object of class |
n |
The sample size per basket. |
r |
A numeric vector of the number of responses in each stratum. |
lambda |
The posterior probability threshold. |
epsilon |
Tuning parameter that determines the amount of borrowing.
See |
tau |
Tuning parameter that determines how similar the baskets
have to be that information is shared. See |
logbase |
Tuning parameter. The base of the logarithm that is used to calculate the Jensen-Shannon divergence. |
weight_fun |
Which functions should be used to calculated the pairwise
weights? Default is |
weight_params |
A list of tuning parameters specific to |
... |
Further arguments. |
A numeric vector of posterior probabilities for all strata.
design_x <- setup_fujikawa_x(k = 3, p0 = 0.2, backend = "exact")
basket_test(design = design_x, n = 20, r = c(2, 7, 19), lambda = 0.95,
epsilon = 2, tau = 0,
logbase = exp(1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.