| opt_design | R Documentation |
Functions for optimizing the tuning parameters of a basket trial
design. This defaults to the function basksim::opt_design.
opt_design(design, ...)
## Default S3 method:
opt_design(design, ...)
design |
An object created with one of the |
... |
Further arguments. |
A matrix with the expected number of correct decisions.
design <- setup_fujikawa_x(k = 3, p0 = 0.2)
# In an actual application, usually increase to at least iter = 1000.
opt_design(design = design,
n = 20, alpha = 0.05,
design_params = list(epsilon = c(1, 2), tau = c(0, 0.5)),
scenarios = get_scenarios(design, 0.5),
prec_digits = 3,
iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.