| pow | R Documentation |
Generic function for calculating the power of a basket trial
design. It defaults to the function pow.default which works similarly to
basksim::toer and does not rely on any baskwrap-specific function.
pow(design, ...)
## Default S3 method:
pow(
design,
n,
p1 = NULL,
lambda,
design_params = list(),
iter = 1000,
data = NULL,
...
)
design |
An object created with one of the |
... |
Further arguments. |
n |
The sample size per basket. |
p1 |
Probabilities under the alternative hypothesis. If
|
lambda |
The posterior probability threshold. |
design_params |
A list of params that is specific to the class of
|
iter |
The number of iterations in the simulation. Is ignored if
|
data |
A data matrix with k column with the number of responses for each
basket. Has to be generated with |
A numeric value.
design <- setup_fujikawa_x(k = 3, p0 = 0.2)
pow(design = design, n = 20, p1 = c(0.2, 0.5, 0.5), lambda = 0.95,
design_params = list(epsilon = 2, tau = 0), iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.