| setup_fujikawa_x | R Documentation |
The fujikawa_x S3 class is similar to the basksim::fujikawa class, but
it has an additional parameter backend, that allows users to decide which
backend should be used for calculation of details (i.e. rejection rates,
power, type-I error rate etc.): the basksim package or the
baskexact package.
setup_fujikawa_x(k, p0, shape1 = 1, shape2 = 1, backend = "sim")
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
shape1 |
First common shape parameter of the beta prior. |
shape2 |
Second common shape parameter of the beta prior. |
backend |
A string, either |
An object of class fujikawa_x.
design <- setup_fujikawa_x(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.